# The following tag is to get correct syntax highlighting for this file in vim text editor
# vim: syntax=spec

Name:       system76-power
Version:    1.2.5
Release:    1
Summary:    system76-power
License:    GPLv3
URL:        https://github.com/pop-os/system76-power

# Detailed information about the source Git repository and the source commit
# for the created rpm package
VCS:        git+git@github.com:szydell/system76-power.git#64bfd26419ee1daea2d20df5786904484b325428:

# git_dir_pack macro places the repository content (the source files) into a tarball
# and returns its filename. The tarball will be used to build the rpm.
Source:     system76-power-64bfd264.tar.gz

#Packages required for build
BuildRequires: cargo
BuildRequires: systemd-rpm-macros
BuildRequires: dbus-devel
%if 0%{?fedora} < 37
BuildRequires: libusb-devel
%else
BuildRequires: libusb-compat-0.1-devel
%endif
#Packages required to work
Requires: dbus-common
Requires: libusb
%if 0%{?fedora} < 37
Requires: libusb
%else
Requires: libusb-compat-0.1 
%endif

# More detailed description of the package
%description
System76 Power Management daemon

%define debug_package %{nil}

#--
%prep
%setup -T -b 0 -q -n system76-power
# Preserve timestamps and install systemd unit files to the proper location.
sed -i Makefile \
    -e 's|install -D -m|install -Dpm|g' \
    -e 's|$(sysconfdir)/systemd/system|%{_unitdir}|g'


# This will invoke `make` command in the directory with the extracted sources.
%build
%make_build DEBUG=1

# This will copy the files generated by the `make` command above into
# the installable rpm package.
%install
%make_install
install -Dpm 0644 "completion/completion.sh" "%{buildroot}%{_datadir}/bash-completion/completions/%{name}"
# do not remove. https://pagure.io/system76/system76-power/issue/2
install -D -m 0644 "debian/%{name}-wake.service" "%{buildroot}/%{_unitdir}/%{name}-wake.service"
install -D -m 0644 "data/com.system76.PowerDaemon.service" "%{buildroot}/%{_unitdir}/com.system76.PowerDaemon.service"

# do after installation
%post
%systemd_post com.system76.PowerDaemon.service

# do before uninstallation
%preun
%systemd_preun com.system76.PowerDaemon.service

# do after unistallation
%postun
%systemd_postun_with_restart com.system76.PowerDaemon.service

# Those files will be in the rpm
%files
%{_bindir}/%{name}
# do not remove. https://pagure.io/system76/system76-power/issue/2
%{_unitdir}/%{name}-wake.service
#
%{_datadir}/bash-completion/completions/%{name}
%{_unitdir}/com.system76.PowerDaemon.service
%{_datadir}/dbus-1/interfaces/com.system76.PowerDaemon.xml
%{_datadir}/dbus-1/system.d/com.system76.PowerDaemon.conf
%{_datadir}/polkit-1/actions/com.system76.PowerDaemon.policy



# These files are owned by the package and are removed on uninstallation,
# but they are not installed.
%ghost %{_sysconfdir}/modprobe.d/%{name}.conf
%ghost %{_sysconfdir}/modules-load.d/%{name}.conf

# Changelog
%changelog
* Mon Apr 28 2025 Marcin Szydelski <marcin@szydelscy.pl> 1.2.4-1
- bump Version to: 1.2.4-1
- fetch upstream
- 1.2.4
- Add bonw16
- 1.2.3: Use HEDT fan curve for thelio-astra-a1.1

* Tue Nov 19 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.2.2-1
- bump Version to: 1.2.2-1
- fetch upstream
- 1.2.2: Use HEDT fan curve for thelio-astra-a1

* Thu Oct 17 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.2.1-1
- bump Version to: 1.2.1-1
- fetch upstream
- feat: add huawei support for charging thresholds
- 1.2.1: Allow use of apm_xgene temperatures
- hid_backlight: Check color_left if color doesn't exist
- hid_backlight: Try system76-dkms path
- Keep TBT active on bonw15-b
- bonw15-b: Disable runtime pm on TBT XHCI
- Wakeup thunderbolt controller on hotplug for bonw15-b
- fix: Match full_charge profile to firmware default values

* Sun Aug 11 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.2.0-4
- bump Version to: 1.2.0-4
- fetch upstream
- Add bonw15-b

* Thu Jul 18 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.2.0-3
- bump Version to: 1.2.0-3
- fetch upstream
- chore: remove use of rustfmt::skip

* Thu May 23 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.2.0-2
- bump Version to: 1.2.0-2
- fix merge issue
- fix: wrong zbus connection used to emit system76-power profile change signals
- fix: emit ActiveProfile changed signals on system76-power profile changes
- fix: downgrade zbus to 3.15.2 to fix property getters in gjs dbus proxies
- chore: dbus conf for ppd
- chore(deb): 1.2.0 changelog
- feat: register net.hadess.PowerProfiles as well
- fix: typo in interface name for zbus client
- fix: add PowerProfiles Profiles property
- fix: typo in dbus name
- improv: add ProfileReleased signal for upower power profiles
- improv: implement hold_profile and release_profile methods for upower power
profiles
- chore(deb): define as providing/replacing power-profiles-daemon
- feat: register dbus service at org.freedesktop.UPower.PowerProfiles
- improv!: refactor from dbus crate to zbus 4.1

* Tue May 21 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.2.0-1
system76-power-1.2.0-1

* Thu May 02 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.1.26-3
- bump Version to: 1.1.26-3
- fetch upstream
- Gracefully handle missing brightness_hw_changed

* Tue Mar 26 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.1.26-2
- bump Version to: 1.1.26-2
- fetch upstream
- fear: allow using Performance power profile on desktop

* Thu Mar 14 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.1.26-1
- bump Version to: 1.1.26-1
- fetch upstream
- 1.1.26
- Add oryp12
- Add addw4
- bump Version to: 1.1.25-9
- fetch upstream
- feat: notify in CLI if system is incompatible
- chore: Refactor/clippy (#418)

* Thu Feb 15 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-8
rebuild for F40
- bump Version to: 1.1.25-8

* Wed Feb 14 2024 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-7
try to rebuild for epel9 too
- bump Version to: 1.1.25-7

* Tue Dec 05 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-6
- bump Version to: 1.1.25-6

* Tue Dec 05 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-5
- bump Version to: 1.1.25-5
- change service name

* Mon Nov 27 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-4
- bump Version to: 1.1.25-4

* Sun Nov 26 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-3
- bump Version to: 1.1.25-3

* Sun Nov 26 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-2
- bump Version to: 1.1.25-2

* Sun Nov 26 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.25-1
- bump Version to: 1.1.25-1
- Merge branch 'pop-os:master' into master
- feat: amd-pstate-epp energy_performance_preference config support
- Warn if determining runtimepm support fails
- Fix finding supported GPUs file when transitional packages are installed
- Control nvidia hibernate, resume, and suspend services for bonw15
- Disable PreserveVideoMemoryAllocations on bonw15
- hid_backlight: Correct colors on bonw15
- Format
- Move bonw15 GPU runtime PM workaround to graphics module
- bonw15: runtime PM quirk for NVIDIA GPU
- Trim DMI vendor and model
- Disable runtime power management on bonw15 TBT XHCI
- 1.1.25
- Probe thelio_io_2 and control pwm3 and pwm4
- chore: remove unused disks module
- Update deps to fix CVE-2023-22466 (#402)
- Note that switchable graphics is not for desktops
- Fix serw13 USB-C hot-plug detect and use 0xFF for no pin

* Tue May 23 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.24-5
- bump Version to: 1.1.24-5
- fetch upstream
- Add RPL boards

* Tue Mar 07 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.24-4
- bump Version to: 1.1.24-4

* Wed Jan 25 2023 Marcin Szydelski <marcin@szydelscy.pl> 1.1.24-3
- bump Version to: 1.1.24-3
- fetch upstream
- ci: Remove use of actions-rs
- ci: Update checkout action to v3
- fix: Disable runtime PM for PCI and I2C devices
- fix: Disable the USB auto runtime PM
- fix: Limit to Rust 1.61.0 for Ubuntu compatibility
- chore: Update debian/rules
- feat: Enable runtime PM for I2C, PCI, USB devices to satisfy "bad" powertop
reports
- feat(acpi-platform): Fix for systems with `quiet` instead of `low-power`
- feat(cpufreq): Support amd-pstate and amd-pstate-epp
- typo
- graphics: Do not report desktops as switchable
- parsing type error fix (#369)

* Tue Nov 08 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.24-2
- bump Version to: 1.1.24-2
- Clean unneeded const

* Tue Nov 08 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.24-1
- bump Version to: 1.1.24-1
- fetch upstream
- chore: fmt
- chore(release): 1.1.24
- chore: rust-toolchain 1.65
- chore: Update dependencies
- chore: Apply various lints from clippy

* Wed Nov 02 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.23-2
- bump Version to: 1.1.23-2
- fetch upstream
- Add profile information to README (#353)

* Mon Sep 05 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.23-1
- bump Version to: 1.1.23-1
- fetch upstream
- 1.1.23
- hotplug: Add oryp10 detection
- Update edition to 2021, deps

* Sat Aug 13 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.22-4
- bump Version to: 1.1.22-4

* Thu Aug 04 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.22-3
- bump Version to: 1.1.22-3

* Wed Aug 03 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.22-2
- bump Version to: 1.1.22-2
- fetch upstream
- Drop dependency on ubuntu-drivers-common

* Thu Jul 21 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.22-1
- services
- bump Version to: 1.1.22-1
- Merge branch 'master' of github.com:szydell/system76-power
- done
- hotplug: Add oryp9 detection (#323)
- tidy up the errors a little
- 1.1.21
- Add gaze17
- ci: Update before installing dependencies
- Configure Xserver when switching modes
- fix: Symlink for system76-power.service not being created
- chore: Add system76-power.service as an alias
- graphics: Assume RTD3 for NVIDIA only
- graphics: Get NVIDIA GPU features without driver loaded
- Disable dGPU if it doesn't support runtimepm
- Update dependencies
- readme: Add note about muxed DP HPD
- daemon: Move self named file to mod file
- hotplug: Use Self when returning structs
- hotplug: Use HotPlugDetectError for mux detect
- Move sideband and mux to hotplug module
- Move hotplug.rs to a mod file
- Move REQUIRES_NVIDIA from hotplug to graphics
- improv: Use clap 3 derive macro for argument parsing
- Correctly apply changes to all CPU cores
- chore(deb): Conflict with power-profiles-daemon
- fix: Improve systemd service packaging
- fix(daemon): Use "balanced" for acpi-platform balanced setting

* Thu Jul 21 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-12
- bump Version to: 1.1.20-12

* Tue Jun 07 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-11
- bump Version to: 1.1.20-11
- libusb-compat for f37+

* Tue Jun 07 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-10
- bump Version to: 1.1.20-10

* Tue Jun 07 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-9
- bump Version to: 1.1.20-9

* Sat Apr 09 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-8
- bump Version to: 1.1.20-8
- fetch upstream
- daemon: Always enable GPU power
- graphics: Configure runtimepm in sysfs
- graphics: Replace strings for mode with an enum

* Mon Mar 21 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-7
- bump Version to: 1.1.20-7
- fetch upstream
- fix: Choose scaling governor more wisely

* Sun Mar 13 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-6
- fetch upstream
- bump Version to: 1.1.20-6
- fix: Use powersave on balanced profile
- feat: Use schedutil governor if scaling driver is acpi-cpufreq
- chore: Remove unnecessary CI features
- feat: Support setting Intel HWP Dynamic Boost
- chore: Remove rust-toolchain
- chore(vscode): Set clippy as default checkOnSave command
- feat: Achieve higher CPU turbo boosts with cpufreq adjustments

* Sat Jan 29 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-5
- bump Version to: 1.1.20-5
- restore wake.service

* Fri Jan 28 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-4
- bump Version to: 1.1.20-4
- initramfs->dracut

* Fri Jan 28 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-3
- bump Version to: 1.1.20-3
- treshold->s

* Fri Jan 28 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-2
- bump Version to: 1.1.20-2
- init
- +.rpkg-build/

* Fri Jan 28 2022 Marcin Szydelski <marcin@szydelscy.pl> 1.1.20-1
- bump Version to: 1.1.20-1
- /etc/dbus-1/interfaces/com.system76.PowerDaemon.xml
- dracut
- Merge pull request #48 from gotmax23/master
- Make more compliant with Packaging Guidelines
- Remove unnecessary and buggy `system76-power-wake.service`

* Fri Jan 28 2022 Marcin Szydelski <marcin@szydelscy.pl> 0.51-1
- Merge branch 'pop-os:master' into master
- fix: Handle lack of color on some keyboard LEDs
- Merge branch 'pop-os:master' into master
- graphics: Preserve video memory during sleep
- 1.1.20 - AMD+NVIDIA hot plug detection, kudu6
- readme: Add note for AMD hot plug detection
- hotplug: Add kudu6 detection
- hotplug: Shoehorn in AMD support
- Add const for MMIO BAR of Intel PCH sideband bus
- Update dependencies
- Merge branch 'pop-os:master' into master
- Add gaze16-3060-b
- Merge branch 'pop-os:master' into master
- feat: Use Linux's ACPI Platform Profiles when available
- chore: Apply lints and fixes for Clippy
- Add arm64 builds
- chore: Apply SPDX license identifiers
- fix(debian): Correct placement of files in system
- feat: Add DBus XML file to `dbus-1/interfaces`
- chore: Replace err-derive with thiserror
- chore: Upgrade dependencies
- run tests in CI
- bump codecov action version
- add coverage workflow

* Sat Sep 18 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.50-1
- Merge branch 'pop-os:master' into master
- chore(rust): Update MSRV to 1.51.0

* Thu Sep 16 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.49-1
- Merge branch 'pop-os:master' into master
- Add oryp8
- Update dependencies

* Tue Aug 03 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.48-1
- treshold->tresholds

* Fri Jul 30 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.47-1
- Merge branch 'pop-os:master' into master
- fix: Avoid setting APM parameters for disks due to some disks having faulty
support
- 1.1.17
- Add gaze16

* Tue Jul 13 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.46-1
- charge-thresholds

* Tue Jul 13 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.45-1
- Merge branch 'pop-os:master' into master
- Document hotplug support
- fan: Assume temperature is always above freezing
- Update dependencies, lockfile format

* Mon Jul 12 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.44-1
- Merge branch 'pop-os:master' into master
- Edit typo in daemon help

* Wed Jun 16 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.43-1
- Merge pull request #46 from pop-os/master
- Fixed typo in charge_thresholds.rs

* Tue May 04 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.42-1
- Merge pull request #45 from pop-os/master
- Document that a reboot is required after switching

* Wed Apr 21 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.41-1
- 21.04.2021 merge
- refactor src/module
- use 2018-style modules
- use explicit imports

* Tue Apr 06 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.40-1
- Merge pull request #43 from pop-os/master
- add missing newline
- use implicit 'iter'
- collapse identical match blocks
- use implicit 'iter'
- remove stuttering in logging module
- remove stuttering in logging module
- add libusb dep
- add libdbus dep to CI
- add CI target for clippy
- refactor clippy lints
- enforce and fix formatting
- Merge pull request #42 from pop-os/master
- chore(debian): Update use of debhelper
- Merge pull request #41 from pop-os/master
- Replace dh-systemd with debhelper version requirement

* Wed Mar 03 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.39-1
- Merge pull request #40 from pop-os/master
- Add oryp7

* Mon Feb 08 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.38-1
- Merge pull request #39 from pop-os/master
- 1.1.15
- Mira WIP fan curve
- readme: Update reverse PRIME and runtimepm info
- 1.1.14 - Add thelio-major-b3

* Mon Feb 01 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.37-1
- +%{_datadir}/polkit-1/actions/com.system76.powerdaemon.policy
- Merge pull request #38 from pop-os/master
- chore: Bump version and update changelog for charge thresholds
- feat(cli): Allow setting charge thresholds by profile name
- feat: GetChargeProfiles dbus method
- feat: Add dbus API and CLI for battery charge thresholds
- 1.1.12 - Use hybrid graphics by default for galp5
- allow for profile to not set tdp since galp5 on 20.10 doesnt seem to like it,
add galp5 profiles
- Allow gnome-initial-setup to send/receive via dbus.
- Report integrated if checking RTD3 support fails

* Sat Jan 30 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.36-1
- Merge pull request #37 from pop-os/master
- Move XEON curve max fans from 83 to 78

* Fri Jan 01 2021 Marcin Szydelski <marcin@szydelscy.pl> 0.35-1
- Merge pull request #36 from pop-os/master
- Add DBus method for NVIDIA external display check

* Wed Dec 30 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.34-1
- Merge pull request #35 from pop-os/master
- Determine default graphics by runtimepm support

* Thu Dec 24 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.33-1
- Merge pull request #34 from pop-os/master
- Add GetDefaultGraphics DBus method

* Thu Nov 19 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.32-1
- Merge pull request #33 from pop-os/master
- improv: Remove unused include
- improv: Remove unused vergen dependency and build.py

* Wed Nov 04 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.31-1
- Change sudo for wheel
- Merge pull request #31 from pop-os/master
- improv: Use dbus-tokio for server
- improv: Use dbus-crossroads instead of dbus-tree
- chore: Update to dbus-rs 0.9.0
- improv: Use dbus::blocking::* instead of dbus::ffidisp::*
- Disable loading nvidia-drm in compute mode
- 1.1.11 - Add thelio-major-r2.1 and thelio-mega-r1.1
- fix(Makefile): Do not set setuid bit
- Improve thelio-major-b1 fan curve
- 1.1.10 - Add bonw14 displayport mux support
- 1.1.9 - gaze15: Determine variant by NVIDIA device
- Update dependencies

* Mon Aug 24 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.29-1
- +requires libusb
- Merge pull request #30 from pop-os/master
- move systemd .service to /etc/systemd/system
- +compute
- feat: Make PowerClient type public
- 1.1.8 - Make HID keyboard backlight update block for events
- 1.1.7 - Add HID keyboard backlight support
- Merge pull request #29 from pop-os/master
- Update to Rust 1.41.0
- fix(Makefile): Fix the problem of missing .service file after make install
- fix(TESTING.md): The cmd about 'graphics power state' in TESTING.md is wrong.

* Mon Jul 06 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.28-1
- + compute option
- Merge pull request #28 from pop-os/master
- Add "compute" graphics mode
- Explicitly require ubuntu-drivers-common

* Tue Jun 30 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.27-1
- rename intel to integrated
- Merge pull request #27 from pop-os/master
- fixed fan unit tests
- Add oryp6
- Merge pull request #26 from pop-os/master
- Use TR3 fan curve for thelio-major-b2
- 1.1.5 - Add model-specific power profile for lemp9
- Update fan.rs
- Add Type and BusName options to systemd service
- Blacklist i2c_nvidia_gpu in hybrid mode
- readme: Remove note about udev rules file
- Rename Intel mode to integrated mode
- Allow switching on AMD+NVIDIA systems

* Mon Apr 27 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.26-1
- Merge pull request #25 from pop-os/master
- 1.1.4 - add addw2 and gaze15

* Sat Feb 22 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.25-1
- Merge pull request #24 from pop-os/master
- 1.1.3
- Initial Threadripper 3 Fan Curves

* Sun Jan 19 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.24-1
- Merge pull request #22 from pop-os/master
- Add Thelio Mega

* Tue Jan 07 2020 Marcin Szydelski <marcin@szydelscy.pl> 0.23-1
- Merge pull request #21 from pop-os/master
- Merge pull request #132 from pop-os/thelio-major-r2
- Add XEON fan curve and setup thelio-massive-b1 to use it.
- Merge branch 'master' into thelio-major-r2
- 1.1.2
- Add thelio-major-r2

* Fri Dec 27 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.22-1
- Merge pull request #20 from pop-os/master
- Upgrade to dbus 0.7.1
- Add explicit 'dyn' to trait objects
- Update toolchain to 1.39.0
- Delete rust.yml

* Fri Nov 15 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.21-1
- Merge pull request #19 from pop-os/master
- improvement: Added Core X fan curve, and improved the standard curve
- rust auto test/build

* Wed Nov 13 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.20-1
- Merge pull request #18 from pop-os/master
- improvement: Change power profile only if it is not already set

* Sat Nov 02 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.19-1
- add hybrid

* Sat Nov 02 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.18-1
- Merge pull request #17 from pop-os/master
- Update fan tests
- Fix fan example

* Mon Oct 28 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.17-1
HYBRID mode
- spec
- README.md
- Add notes about graphics modes in README
- Add support for PRIME render offloading
- Merge pull request #15 from pop-os/master
- Fix typo

* Sun Oct 06 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.16-1
- Merge pull request #14 from pop-os/master
- Add darp6 and galp4 to automatic display switching

* Tue Jul 30 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.15-1
- Merge pull request #13 from pop-os/master
- Merge pull request #94 from pop-os/persistable-brightness
- Merge branch 'master' into threadripper-fan
- :memo: Add TESTING.md
- Trim model name
- Add new fan curve for thelio-major-r1
- :sparkles: Don't set brightness when setting the initial profile

* Tue Jul 02 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.14-1
- Merge pull request #12 from pop-os/master
- Skip setting APM for md-raid devices
- addp1 -> addw1
- Add addp1 to hotplug daemon

* Mon Jun 17 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.13-1
- patch that allows to run this software on Fedora
- merge
- from master
- marge with master, fedora specific changes temporarily lost

* Tue May 14 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.12-1
- Merge pull request #9 from pop-os/master
- Merge branch 'master' into gaze14
- Add 17 inch version PCI IDs
- Add support for 1650 model
- Update ports for gaze14 hotplug detection
- Add gaze14 to hotplug detection

* Wed May 08 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.11-1
- Merge pull request #8 from pop-os/master
- Support multiple I/O boards and multiple CPUs

* Wed Apr 17 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.10-1
- Merge pull request #7 from pop-os/master
- Disable another nvidia kernel module

* Thu Mar 28 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.9-1
- additional daemon paramenters
- Merge pull request #6 from pop-os/master
- Merge branch 'master' into autoswitch
- Merge pull request #5 from pop-os/master
- Merge branch 'master' into ignore-initial-profile-error
- Merge branch 'master' into power-client
- Merge branch 'master' into ignore-initial-profile-error
- :hear_no_evil: Allow the initial profile on startup to fail
- Merge branch 'master' into autoswitch
- Add previous generation settings
- Add displayport mux to daemon
- Example of automatic displayport switching for the galago/darter
- :hammer: Simpler power client method calling

* Mon Mar 25 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.8-1
- Merge pull request #4 from pop-os/master
- Merge branch 'master' into get-profile
- :sparkles: Add PowerProfileSwitch signal
- :sparkles: Add GetProfile dbus method

* Tue Mar 05 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.7-1
- Merge pull request #3 from pop-os/master
- :sparkles: Detect AMD graphics devices

* Fri Feb 08 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.6-1
- new power on/off/auto option in graphics
- Merge pull request #2 from pop-os/master
- Move sideband logic to a separate file, add gpio example

* Fri Feb 01 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.5-1
- Merge branch 'master' of github.com:szydell/system76-power
- Update README.md

* Fri Feb 01 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.4-1
- restart system76-daemon after suspend

* Fri Feb 01 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.3-1
- Merge pull request #1 from pop-os/master
- Track all sub-functions of graphics devices, not just audio. Update
dependencies
- Add oryp5 hotplug detection
- bash completion
- + vim swap

* Mon Jan 07 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.2-1
- copr
- copr
- + After, + Service type

* Mon Jan 07 2019 Marcin Szydelski <marcin@szydelscy.pl> 0.1-1
Initial RPM release

- rpm spec for rpkg/copr
- Send 'command' output to /dev/null
- dracut or update-initramfs
- :arrow_up: Update dependencies
- :ambulance: Fix the build
- :truck: Migrate PciDevice / PciDriver to sysfs-class
- :paperclip: Clippy fixes
- :package: pstate module -> intel-pstate crate
- Merge branch 'master' of github.com:pop-os/system76-power into sysfs
- Export /sys/class logic to sysfs-class
- Merge pull request #49 from pop-os/fan
- Conditionally handle pstate based on availability
- Support AMD cpu on thelio-r1
- Add extra test cases for fan point interpolation
- Fix the test inputs
- Use a windows iterator
- Add fan tests
- Fix clippy suggestions / warnings
- Fix bionic builds
- USe sysfs-class from crates.io
- Remove debug print
- Improve fan curve
- WIP: Fan control
- Daemon flags fixed.
- Set version to 1.0.0
- Add GetSwitchable DBUS Method
- Remove breaking switchable text
- Merge branch 'master' into argparse
- system76-power graphics: improve output
- Improve help messages
- Initialize daemon with balanced profile
- Enable Runtime Power Management for PCI Devices
- Setup logging before the daemon is launched
- Merge branch 'master' of github.com:pop-os/system76-power into argparse
- Fix argument parsing
- Update graphics power off/on message to clarify discrete graphics
- Use clap for argument parsing
- Revert Clap Changes
- Make log level configurable
- Enable logging with fern
- Integrate Disk power management
- Control autosuspend_delay
- SATA Link Power Policy Control
- Merge branch 'kernel-parameters' of github.com:pop-os/system76-power into
kernel-parameters
- Implement experimental flag & Use Clap
- Merge branch 'master' into kernel-parameters
- Fix snd
- Fix Wifi power saving support
- Fix static parameters
- iwlwifi power management
- Control Laptop Mode
- Disable NMI Watchdog & Set Dirty Page Values
- Radeon power support
- Enable power savings for sound devices
- Implement structs for various kernel parameters
- Merge branch 'master' of github.com:pop-os/system76-power into macros
- Add hotplug signal
- Macros
- Match more graphics cards
- Remove NVIDIA audio as well as NVIDIA graphics
- Simplify Graphics::auto_power
- Simplify Graphics::get_power
- Fix println instead of eprintln
- Provides and replaces nvidia-prime again
- Bump version. Remove replaces and provides nvidia-prime
- Increase timeout
- Remove bbswitch blacklist
- Replace and provide nvidia-prime
- Automatically set graphics power during boot, logging output
- Modify command line to use DBUS
- Improve graphics struct
- Move graphics to separate file
- Add unsafe
- Remove NVIDIA device when possible
- Better output
- Driver detection
- WIP: Remove bbswitch dependency, add pci subcommand to search for graphics
devices
- 0.1.1
- Update Cargo.lock
- Add DBUS function for automatic graphics power
- Remove graphics power auto as it appears to prevent boot
- Automatically disable GPU power on boot
- Do not try fsync on bbswitch file
- Add auto graphics power mode
- Add code to set graphics power
- Create ISSUE_TEMPLATE.md
- Detect nouveau as nvidia
- Conflict with nvidia-prime
- Merge branch 'master' into optimus
- Disable bbswitch load_state
- Check if the intel_pstate directory exists
- Handle nvidia-fallback.service to prevent nouveau from being loaded, add
postrm hook
- Update intel blacklist to prevent nouveau loading
- Create README.md
- Create LICENSE
- Correct dependencies
- Remove dbus examples
- Add system76-power service
- WIP: Create a dbus daemon
- Require optimus to set graphics, restore setuid bit
- Create modules-load file
- Fix backwards graphics selection
- Write blacklist and update initramfs
- WIP: Do not use nvidia-prime
- Update gitignore
- Add graphics selection
- Fix changelog version
- Fix makefile
- Add debian packaging
- Support any display backlight or keyboard backlight
- Commit Cargo.lock
- Only set brightness if it is higher than expected
- Add makefile
- add todo to only decrease brightness
- Adjust balanced and battery backlights
- Make set functions require mut
- Add three performance profiles
- Add keyboard backlight
- Move backlight to seperate file
- Initial commit
